import gtk
import hildon

class google_link:

    def __init__(self,osmMapa,CONFIG):
        self.osmMapa = osmMapa
        self.CONFIG = CONFIG

        self.ico = "google_maps.png"
        self.ui_menu_main = 1
        self.ui_menu_left = 0
        self.ui_stackable = 0
        self.ui_search = 0


        print "__init__ google_link"

    def get_menu_widgets(self, dialog):
        lat = self.osmMapa.osm.props.latitude
        lon = self.osmMapa.osm.props.longitude
        zoom = self.osmMapa.osm.props.zoom

        hbox = gtk.HBox()

        en_location = gtk.Entry()
        url = "http://maps.google.com/maps?z=%i&q=loc:%f+%f" % (zoom,lat,lon )
        en_location.set_text( url )
        hbox.pack_start(en_location, True)

        if self.osmMapa.send_to_contact_present():
            hbox.pack_start(self.osmMapa.send_to_contact_dialog(url), False)

        return hbox

    def get_name(self):
        return "Google - link"

    def do_draw(self, gpsmap, gdkdrawable):
        pass

    def do_render(self, gpsmap):
        pass

    def do_busy(self):
        return False

    def do_button_press(self, gpsmap, gdkeventbutton):
        pass